@@ -8,11 +8,10 @@
 #' @param ylab a label of the plot's y-axis. The default uses the value of \code{qi}.
 #' @param title the plot's main title.
 #' @param smoother what type of smoothing line to use to summarize the plotted coefficient.
-#' @param spalette colour palette for use in \code{qi = "Hazard Rate"}. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
-#' @param leg.name name of the stratified hazard rates legend. Only relevant if \code{qi = "Hazard Rate"}.
-#' @param lcolour character string colour of the smoothing line. The default is hexadecimal colour \code{lcolour = '#2B8CBE'}. Only relevant if \code{qi = "Relative Hazard"} or \code{qi = "First Difference"}.
-#' @param lsize size of the smoothing line. Default is 2. See \code{\link{ggplot2}}.
-#' @param pcolour character string colour of the simulated points for relative hazards. Default is hexadecimal colour \code{pcolour = '#A6CEE3'}. Only relevant if \code{qi = "Relative Hazard"} or \code{qi = "First Difference"}.
+#' @param spalette colour palette for when there are multiple sets of comparisons to plot. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
+#' @param legend specifies what type of legend to include (if applicable). The default is \code{legend = "legend"}. To hide the legend use \code{legend = FALSE}. See the \code{\link{discrete_scale}} for more details.
+#' @param leg.name name of the legend (if applicable).
+#' @param lsize size of the smoothing line. Default is 1. See \code{\link{ggplot2}}.
 #' @param psize size of the plotted simulation points. Default is \code{psize = 1}. See \code{\link{ggplot2}}.
 #' @param alpha point alpha (e.g. transparency) for the points or ribbons. Default is \code{alpha = 0.1}. See \code{\link{ggplot2}}.
 #' @param ribbons logical specifies whether or not to use summary ribbons of the simulations rather than plotting every simulation value as a point. If \code{ribbons = TRUE} a plot will be created with shaded areas ('ribbons') for the minimum and maximum simulation values (i.e. the middle interval set with \code{qi} in \code{\link{coxsimtvc}}) as well as the central 50 percent of this area. It also plots a line for the median value of the full area, so values in \code{smoother} are ignored. One of the key advantages of using ribbons rather than points is that it creates plots with smaller file sizes.
@@ -30,8 +29,8 @@
 #' # library(survival)
 #' 
 #' # Create natural log time interactions
-#' #Golubtvc <- function(x){
-#' #  assign(paste0("l", x), tvc(GolubEUPData, b = x, tvar = "end", tfun = "log"))
+#' # Golubtvc <- function(x){
+#' # tvc(data = GolubEUPData, b = x, tvar = "end", tfun = "log")
 #' # }
 #' 
 #' # GolubEUPData$Lcoop <-Golubtvc("coop")
@@ -70,7 +69,7 @@
 #' #                  by = 15, ci = 0.99)
 #'                   
 #' # Create plots
-#' # simGG(Sim1)
+#' # simGG(Sim1, legend = FALSE)
 #' # simGG(Sim2)
 #' # simGG(Sim3, leg.name = "Comparision", from = 1200, ribbons = TRUE)
 #'
@@ -81,12 +80,15 @@
 #'
 #' @references Licht, Amanda A. 2011. ''Change Comes with Time: Substantive Interpretation of Nonproportional Hazards in Event History Analysis.'' Political Analysis 19: 227-43.
 
-simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", leg.name = "", lcolour = "#2B8CBE", lsize = 2, pcolour = "#A6CEE3", psize = 1, alpha = 0.1, ribbons = FALSE, ...)
+simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", legend = "legend", leg.name = "", lsize = 1, psize = 1, alpha = 0.1, ribbons = FALSE, ...)
 {
   Time <- HRate <- HRValue <- QI <- Comparison <- Xj <- Lower50 <- Upper50 <- Min <- Max <- Median <- NULL
   if (!inherits(obj, "simtvc")){
     stop("must be a simtvc object")
   }
+  if (isTRUE(ribbons) & smoother != "auto"){
+    message("The smoother argument is ignored if ribbons = TRUE. Central tendency summarised with the median.")
+  }
 
   # Find quantity of interest
   qi <- class(obj)[[2]]
@@ -116,18 +118,18 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_smooth(method = smoother, size = lsize, se = FALSE) +
           facet_grid(.~ Strata) +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
       } else if (is.null(obj$Strata)){
           ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
             geom_point(shape = 21, alpha = I(alpha), size = psize) +
             geom_smooth(method = smoother, size = lsize, se = FALSE) +
-            scale_colour_brewer(palette = spalette, name = leg.name) +
+            scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
             xlab(xlab) + ylab(ylab) +
             ggtitle(title) +
-            guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+            #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
             theme_bw(base_size = 15)
       }
     } else if (qi == "Hazard Ratio"){
@@ -136,9 +138,9 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_smooth(method = smoother, size = lsize, se = FALSE) +
           geom_hline(aes(yintercept = 1), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
     } else if (qi == "Relative Hazard"){
         ggplot(obj, aes(x = Time, y = QI, colour = factor(Xj))) +
@@ -146,19 +148,19 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_smooth(method = smoother, size = lsize, se = FALSE) +
           geom_hline(aes(yintercept = 1), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
     } else if (qi == "First Difference"){
-        ggplot(obj, aes(Time, QI, group = Comparison)) +
-          geom_point(shape = 21, alpha = I(alpha), size = psize, colour = pcolour) +
-          geom_smooth(method = smoother, size = lsize, se = FALSE, color = lcolour) +
+        ggplot(obj, aes(Time, QI, colour = factor(Comparison))) +
+          geom_point(shape = 21, alpha = I(alpha), size = psize) +
+          geom_smooth(method = smoother, size = lsize, se = FALSE) +
           geom_hline(aes(yintercept = 0), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1)), colour = FALSE) +
           theme_bw(base_size = 15)
     }
   }
@@ -174,10 +176,10 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) +
           facet_grid(. ~ Strata) +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
-          scale_fill_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
       } else if (is.null(obj$Strata)){
       obj <- MinMaxLines(df = obj, hr = TRUE)
@@ -185,11 +187,11 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
             geom_line(size = lsize) +
             geom_ribbon(aes(ymin = Lower50, ymax = Upper50), alpha = alpha, linetype = 0) +
             geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) +
-            scale_colour_brewer(palette = spalette, name = leg.name) +
-            scale_fill_brewer(palette = spalette, name = leg.name) +
+            scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+            scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) +
             xlab(xlab) + ylab(ylab) +
             ggtitle(title) +
-            guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+            #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
             theme_bw(base_size = 15)
       }
     } else if (qi == "Hazard Ratio"){
@@ -201,44 +203,38 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
             geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) + 
             geom_hline(aes(yintercept = 1), linetype = "dotted") + 
             xlab(xlab) + ylab(ylab) + 
-            scale_colour_brewer(palette = spalette, 
-            name = leg.name) + 
-            scale_fill_brewer(palette = spalette, 
-            name = leg.name) + 
+            scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) + 
+            scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) + 
             ggtitle(title) + 
-            guides(colour = guide_legend(override.aes = list(alpha = 1))) + 
+            #guides(colour = guide_legend(override.aes = list(alpha = 1))) + 
             theme_bw(base_size = 15)
     } else if (qi == "Relative Hazard"){
       obj <- MinMaxLines(df = obj, byVars = c("Time", "Xj"))
       ggplot(obj, aes(x = Time, y = Median, colour = factor(Xj), fill = factor(Xj))) +
-          geom_line(size = lsize, colour = lcolour) + 
+          geom_line(size = lsize) + 
           geom_ribbon(aes(ymin = Lower50, ymax = Upper50), 
             alpha = alpha, linetype = 0) + 
           geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) + 
           geom_hline(aes(yintercept = 1), linetype = "dotted") + 
           xlab(xlab) + ylab(ylab) + 
-          scale_colour_brewer(palette = spalette, 
-          name = leg.name) + 
-          scale_fill_brewer(palette = spalette, 
-          name = leg.name) + 
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) + 
+          scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) + 
           ggtitle(title) + 
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) + 
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) + 
           theme_bw(base_size = 15)
     } else if (qi == "First Difference"){
       obj <- MinMaxLines(df = obj, byVars = c("Time", "Comparison"))
-      ggplot(obj, aes(x = Time, y = Median, group = Comparison)) +
-          geom_line(size = lsize, colour = lcolour) + 
+      ggplot(obj, aes(x = Time, y = Median, colour = factor(Comparison), fill = factor(Comparison))) +
+          geom_line(size = lsize) + 
           geom_ribbon(aes(ymin = Lower50, ymax = Upper50), 
             alpha = alpha, linetype = 0) + 
           geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) + 
           geom_hline(aes(yintercept = 0), linetype = "dotted") + 
           xlab(xlab) + ylab(ylab) + 
-          scale_colour_brewer(palette = spalette, 
-          name = leg.name) + 
-          scale_fill_brewer(palette = spalette, 
-          name = leg.name) + 
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) + 
+          scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) + 
           ggtitle(title) + 
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) + 
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) + 
           theme_bw(base_size = 15)
     }
     )
